==> tine20-exampleapplication_2016.11.24.tar.bz2: ExampleApplication/js/ExampleApplication-lang-hu-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: \nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 12:53+0000\nLast-Translator: Faragó Tamás <Unknown>\nLanguage-Team: gump <admin@kemenyfem.hu>\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=n != 1;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Country: HUNGARY\nX-Poedit-Language: Hungarian\nX-Poedit-SourceCharset: utf-8\n"

, "Status Available"
: "Állapot elérhető"

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: "Lehetséges állapot. Kérlek jegyezd meg, hogy a további állapotok ütközhetnek a más Példa Alkalmazás rendszerekkel exportálások vagy szinkronizáláskor."

, "%s's personal example records"
: "%s személyes példa rekordjai"

, "Example Application test"
: "Példa Alkalmazás teszt"

, "ExampleRecord"
: "PéldaRekord"

, "Name"
: "Név"

, "Status"
: "Státusz"

, "Title"
: "Beosztás"

, "Budget"
: "Költség"

, "Show closed"
: "Mutasd a lezártakat"

, "example record, example records"
: [
  "példa rekord"
 ,"példa rekordok"

]
, "example record list, example record lists"
: [
  "példa rekord lista"
 ,"példa rekord listák"

]
, "Quick Search"
: "Gyors keresés"

, "Last modified"
: "Utoljára módosítva"

, "Last modifier"
: "Utoljára módosította"

, "Creation Time"
: "Készítés ideje"

, "Creator"
: "Készítő"

, "Completed"
: "Teljesítve"

, "Cancelled"
: "Lemondva"

, "In process"
: "Feldolgozás alatt"

, "ExampleApplication"
: "PéldaAlkalmazás"

, "Example Application"
: "Példa Alkalmazás"

, "example record"
: "példa rekord"

, "example record list"
: "példa rekord lista"

}));

==> tine20-exampleapplication_2017.08.11.tar.bz2: ExampleApplication/js/ExampleApplication-lang-hu-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: \nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 12:53+0000\nLast-Translator: Faragó Tamás <Unknown>\nLanguage-Team: gump <admin@kemenyfem.hu>\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=n != 1;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Country: HUNGARY\nX-Poedit-Language: Hungarian\nX-Poedit-SourceCharset: utf-8\n"

, "ExampleRecord"
: "PéldaRekord"

, "Name"
: "Név"

, "Status"
: "Státusz"

, "Reason"
: ""

, "Total Example Records"
: ""

, "New Example"
: ""

, "Status Available"
: "Állapot elérhető"

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: "Lehetséges állapot. Kérlek jegyezd meg, hogy a további állapotok ütközhetnek a más Példa Alkalmazás rendszerekkel exportálások vagy szinkronizáláskor."

, "Completed"
: "Teljesítve"

, "Cancelled"
: "Lemondva"

, "In process"
: "Feldolgozás alatt"

, "Reasons Available"
: ""

, "Possible status reasons."
: ""

, "Change"
: ""

, "Documentation"
: ""

, "Requirement Changed"
: ""

, "Not Possible"
: ""

, "Implementation"
: ""

, "Review"
: ""

, "Integration"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Example String"
: ""

, "Just an example string for test purpose"
: ""

, "ExampleApplication"
: "PéldaAlkalmazás"

, "example record, example records"
: [
  "példa rekord"
 ,"példa rekordok"

]
, "example records"
: ""

, "example record list"
: "példa rekord lista"

, "example record lists"
: ""

, "Number"
: ""

, "Default Example Record Container"
: ""

, "The default container for new records"
: ""












, "example record"
: "példa rekord"

}));
